<?php

namespace Elementor;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


/**
 *
 * swp-eventpress elementor Contact widget.
 *
 * @since 1.0
 */
class Swp_Eventpress_Contact_Form extends Widget_Base
{

    public function get_name()
    {
        return 'swp-eventpress-contact-form';
    }

    public function get_title()
    {
        return esc_html__('Contact Form', 'swp-eventpress');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return ['swp-eventpress-details'];
    }

    protected function register_controls()
    {

        // general settings
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'swp-eventpress'),
            ]
        );


        $this->add_control(
            'contact_shortcode',
            [
                'label'       => esc_html__('Select your contact form 7', 'itechie-core'),
                'label_block' => true,
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => swp_eventpress_post_query('wpcf7_contact_form'),
            ]
        );


        $this->end_controls_section(); // End general settings


        //title style
        $this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__('Title Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Title Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-details-page-comment-form h2' => 'color: {{VALUE}}',
                ],
            ]
        );


        //title typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'title_typography',
                'label'          => esc_html__('Title Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-details-page-comment-form h2',
            ]
        );

        $this->add_control(
            'summary_color',
            [
                'label' => esc_html__('Summary Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-details-page-comment-form p' => 'color: {{VALUE}}',
                ],
            ]
        );


        //summary typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'summary_typography',
                'label'          => esc_html__('Title Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-details-page-comment-form p',
            ]
        );

        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__('Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-details-page-comment-form' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {

        $settings = $this->get_settings();
?>
         <?php echo do_shortcode('[contact-form-7 id="' . $settings['contact_shortcode'] . '" ]'); ?>
<?php
    }
}

plugin::instance()->widgets_manager->register(new Swp_Eventpress_Contact_Form());
