<?php

namespace Elementor;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


/**
 *
 * swp-eventpress elementor Contact widget.
 *
 * @since 1.0
 */
class Swp_Eventpress_Isotope extends Widget_Base
{

    public function get_name()
    {
        return 'swp-eventpress-isotope';
    }

    public function get_title()
    {
        return esc_html__('Isotope Style', 'swp-eventpress');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return ['swp-eventpress'];
    }

    protected function register_controls()
    {

        // general settings
        $this->start_controls_section(
            'ele_style_one_settings',
            [
                'label' => esc_html__('General Settings', 'swp-eventpress'),
            ]
        );


        $this->add_control(
            'style',
            [
                'label'   => esc_html__('Select Style', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'style-1' => esc_html__('Style 1', 'swp-eventpress'),
                    'style-2'  => esc_html__('Style 2', 'swp-eventpress'),
                    'style-3'  => esc_html__('Style 3', 'swp-eventpress'),
                ),
                'default' => 'style-1'

            ]
        );

        $this->add_control(
            'ppr',
            [
                'label'   => esc_html__('Amount of post to display', 'swp-eventpress'),
                'type'    => Controls_Manager::TEXT,
                'default' => 6
            ]
        );

        $this->add_control(
            'layout',
            [
                'label'   => esc_html__('layout', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    '3' => '4 Column',
                    '4' => '3 Column',
                ),
                'default' => 4

            ]
        );


        $this->end_controls_section(); // End general settings

        $this->start_controls_section(
            'Post_filter_settings',
            [
                'label' => esc_html__('Post Options', 'swp-eventpress'),
            ]
        );


        $this->add_control(
            'select_cat',
            [
                'label'    => esc_html__('Select Category', 'swp-eventpress'),
                'type'     => Controls_Manager::SELECT2,
                'description' => esc_html__('Keep Blank To Display All Categories Job', 'swp-eventpress'),
                'multiple' => true,
                'options'  => swp_eventpress_post_category(),

            ]
        );

        $this->add_control(
            'exclude_cat',
            [
                'label'    => esc_html__('Exclude Category', 'swp-eventpress'),
                'type'     => Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => swp_eventpress_post_category(),
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order by', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'author' => esc_html__('Author', 'swp-eventpress'),
                    'title'  => esc_html__('Title', 'swp-eventpress'),
                    'date'   => esc_html__('Publish Date', 'swp-eventpress'),
                    'event_date'   => esc_html__('Event Date', 'swp-eventpress'),
                    'rand'   => esc_html__('Random', 'swp-eventpress'),
                ),
                'default' => 'date'

            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'desc' => esc_html__('DESC', 'swp-eventpress'),
                    'asc'  => esc_html__('ASC', 'swp-eventpress'),
                ),
                'default' => 'desc'

            ]
        );

        $this->add_control(
            'event_type',
            [
                'label'   => esc_html__('Event Type', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'all' => esc_html__('All Events', 'swp-eventpress'),
                    'past'  => esc_html__('Past Events', 'swp-eventpress'),
                    'future'  => esc_html__('Future Events', 'swp-eventpress'),
                ),
                'default' => 'all'

            ]
        );


        $this->end_controls_section(); // End Filter

        //title settings
        $this->start_controls_section(
            'title_settings',
            [
                'label' => esc_html__('Title Settings', 'swp-eventpress'),
            ]
        );

        $this->add_control(
            'dtitle',
            [
                'label'   => esc_html__('Display', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT2,
                'options' => array(
                    'full' => esc_html__('Full Title', 'swp-eventpress'),
                    'excerpt'  => esc_html__('Excerpt', 'swp-eventpress'),
                ),
                'default' => 'full'

            ]
        );

        $this->add_control(
            'title_excerpt_length',
            [
                'label'   => esc_html__('Title Excerpt Length', 'swp-eventpress'),
                'type'    => Controls_Manager::TEXT,
                'default' => 3,
                'condition' => [
                    'dtitle' => 'excerpt'
                ]
            ]
        );

        $this->add_control(
            'titltag',
            [
                'label'   => esc_html__('Title Tag', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ),
                'default' => 'h5'

            ]
        );

        $this->end_controls_section(); // End title


        // other 
        $this->start_controls_section(
            'other_settings',
            [
                'label' => esc_html__('Other Settings', 'swp-eventpress'),
            ]
        );

        $this->add_control(
            'enable_read_more',
            [
                'label' => esc_html__('Enable Read More Button?', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'swp-eventpress'),
                'label_off' => esc_html__('no', 'swp-eventpress'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


        $this->add_control(
            'open-url',
            [
                'label'   => esc_html__('Where Open Job Post?', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'same-window' => esc_html__('Same Window', 'swp-eventpress'),
                    'new-window' => esc_html__('New Window', 'swp-eventpress'),
                ),
                'default' => 'same-window'

            ]
        );

        $this->add_control(
            'enable_pagination',
            [
                'label' => esc_html__('Enable Pagination?', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'swp-eventpress'),
                'label_off' => esc_html__('no', 'swp-eventpress'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'filter-button-position',
            [
                'label'   => esc_html__('Filter Button Position', 'swp-eventpress'),
                'type'    => Controls_Manager::SELECT,
                'options' => array(
                    'left' => esc_html__('Left', 'swp-eventpress'),
                    'center' => esc_html__('Center', 'swp-eventpress'),
                    'right' => esc_html__('Right', 'swp-eventpress'),
                ),
                'default' => 'left'

            ]
        );

        $this->end_controls_section(); // End sub title


        //title style
        $this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__('Title Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Title Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-inner .content-box .inner-title a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => esc_html__('Title Hover Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-inner .content-box .inner-title:hover a' => 'color: {{VALUE}}',
                ],
            ]
        );

        //title typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'title_typography',
                'label'          => esc_html__('Title Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-single-inner .content-box .inner-title a',
            ]
        );

        $this->end_controls_section();

        //meta style
        $this->start_controls_section(
            'meta_style',
            [
                'label' => esc_html__('Meta Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,

            ]
        );

        $this->add_control(
            'meta_color',
            [
                'label' => esc_html__('Meta Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-list-inner li' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' => ['style-2', 'style-3']
                ]
            ]
        );

        //meta typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'meta_typography',
                'label'          => esc_html__('Meta Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-single-list-inner li',
                'condition' => [
                    'style' => ['style-2', 'style-3']
                ]
            ]
        );


        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__('Icon Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-list-inner li i' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' => ['style-2', 'style-3']
                ]
            ]
        );

        $this->add_control(
            'date_color',
            [
                'label' => esc_html__('Date Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-badge-btn, {{WRAPPER}} .swp-badge-btn-2,{{WRAPPER}} .swp-meta-inner li:last-child' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'date_bg_color',
            [
                'label' => esc_html__('Date Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-badge-btn-2, {{WRAPPER}} .swp-badge-btn' => 'background-color: {{VALUE}}',
                ],

            ]
        );

        $this->add_control(
            'category_color',
            [
                'label' => esc_html__('Category Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-cat' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'style' => 'style-3'
                ]
            ]
        );

        $this->add_control(
            'category_bg_color',
            [
                'label' => esc_html__('Category Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-cat' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'style' => 'style-3'
                ]
            ]
        );

        $this->end_controls_section();

        //summary style
        $this->start_controls_section(
            'summary_style',
            [
                'label' => esc_html__('Summary Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => 'style-1'
                ]
            ]
        );

        $this->add_control(
            'summary_color',
            [
                'label' => esc_html__('Summary Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-inner .content-box p' => 'color: {{VALUE}}',
                ],
            ]
        );

        //Summary typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'summary_typography',
                'label'          => esc_html__('Summary Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-single-inner .content-box p',
            ]
        );

        $this->end_controls_section();

        //read more button style
        $this->start_controls_section(
            'read_more_button_style',
            [
                'label' => esc_html__('Read More Button Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label' => esc_html__('Button Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_bg_color',
            [
                'label' => esc_html__('Button Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-btn' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_hover_bg_color',
            [
                'label' => esc_html__('Button Hover Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-btn:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        //Button typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'button_typography',
                'label'          => esc_html__('Button Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-btn',
            ]
        );

        $this->end_controls_section();

        //filter  button style
        $this->start_controls_section(
            'filter_button_style',
            [
                'label' => esc_html__('Filter Button Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'filter_button_color',
            [
                'label' => esc_html__('Button Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'filter_button_bg_color',
            [
                'label' => esc_html__('Button Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'filter_button_hover_bg_color',
            [
                'label' => esc_html__('Button Hover/Active Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-isotope-btn button:hover, {{WRAPPER}} .swp-isotope-btn button.active' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        //Button typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'filter_button_typography',
                'label'          => esc_html__('Button Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .button ',
            ]
        );

        $this->end_controls_section();

        //other settings
        $this->start_controls_section(
            'other_style',
            [
                'label' => esc_html__('Other Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => ['style-2', 'style-3']
                ]
            ]
        );

        $this->add_control(
            'card_bg_color',
            [
                'label' => esc_html__('Card Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-inner.style-1 .content-box,{{WRAPPER}} .swp-single-inner.style-6' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {

        $settings = $this->get_settings();

        $paged = (get_query_var('page')) ? absint(get_query_var('page')) : 1;

        $paged = (get_query_var('page')) ? absint(get_query_var('page')) : 1;

        $args  = array(
            'post_type'           => 'event',
            'post_status'         => 'publish',
            'ignore_sticky_posts' => 1,
            'posts_per_page'      => $settings['ppr'],
            'paged' => $paged,
        );

        if ($settings['orderby'] == 'event_date') {
            $args['meta_key'] = 'swp_event_date';
            $args['orderby'] = 'meta_value_num';
            $args['order'] = $settings['order'];
        } else {
            $args['orderby'] = $settings['orderby'];
            $args['order']   = $settings['order'];
        }


        if (!empty($_GET['event_cat']) && -1 != $_GET['event_cat']) {
            $args['tax_query'][] = array(
                'taxonomy' => 'event_cat',
                'field'    => 'slug',
                'terms'    =>  sanitize_text_field($_GET['event_cat'])
            );
        } elseif (!empty($settings['select_cat'])) {
            $args['tax_query'][] = array(
                'taxonomy' => 'event_cat',
                'field'    => 'id',
                'terms'    => array_values($settings['select_cat'])
            );
        }


        if (!empty($settings['exclude_cat'])) {
            $args['tax_query'][] = array(
                'taxonomy' => 'event_cat',
                'field'    => 'id',
                'terms'    => array_values($settings['exclude_cat']),
                'operator' => 'NOT IN'
            );
        }

        if ('past' == $settings['event_type']) {
            $args['meta_query'][] = array(
                'key' => 'swp_event_date',
                'value' => strtotime('today'),
                'compare' => '<',
                'type' => 'NUMERIC'
            );
        }

        if ('future' == $settings['event_type']) {
            $args['meta_query'][] = array(
                'key' => 'swp_event_date',
                'value' => strtotime('today'),
                'compare' => '>',
                'type' => 'NUMERIC'
            );
        }

        $swp_eventpress_posts_query = new \WP_Query($args);

        $swp_event_filter_btn_position = 'text-lg-left';
        if ($settings['filter-button-position'] == 'center') {
            $swp_event_filter_btn_position = 'text-lg-center';
        } elseif ($settings['filter-button-position'] == 'right') {
            $swp_event_filter_btn_position = 'text-lg-right';
        }

        include swp_eventpress_get_template('isotope-one.php');
        include swp_eventpress_get_template('isotope-two.php');
        include swp_eventpress_get_template('isotope-three.php');
    }
}

plugin::instance()->widgets_manager->register(new Swp_Eventpress_Isotope());
