<?php

namespace Elementor;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


/**
 *
 * swp-eventpress elementor Contact widget.
 *
 * @since 1.0
 */
class Swp_Eventpress_Sidebar extends Widget_Base
{

    public function get_name()
    {
        return 'swp-eventpress-sidebar';
    }

    public function get_title()
    {
        return esc_html__('Sidebar', 'swp-eventpress');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return ['swp-eventpress-details'];
    }

    protected function register_controls()
    {

        // general settings
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'swp-eventpress'),
            ]
        );


        $this->add_control(
            'title',
            [
                'label'   => esc_html__('Title', 'swp-eventpress'),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__('Event Details', 'swp-eventpress'),
                'label_block' => true
            ]
        );

        $items = new \Elementor\Repeater();

        $items->add_control(
            'title',
            [
                'label' => __('Title', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __('Add Title', 'swp-eventpress'),
                'default' => __('Start Time', 'swp-eventpress'),
                'label_block' => true
            ]
        );

        $items->add_control(
            'sub_title',
            [
                'label' => __('Sub Title', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __('Add Sub Title', 'swp-eventpress'),
                'default' => __('March 05, 8:00 am', 'swp-eventpress'),
                'label_block' => true
            ]
        );

        $items->add_control(
            'icon',
            [
                'label' => __('Icon', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::ICONS,

            ]
        );

        $this->add_control(
            'items',
            [
                'label' => __('Items', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $items->get_controls(),
                'prevent_empty' => false,
                'title_field' => '{{{ title }}}',
            ]
        );


        $this->end_controls_section(); // End general settings


        // style
        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__('Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'widget_title_color',
            [
                'label' => esc_html__('Widget Title Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-event-widget .swp-details li strong' => 'color: {{VALUE}}',
                ],
            ]
        );


        //widget title typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'widget_title_typography',
                'label'          => esc_html__('Widget Title Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-event-widget .swp-details li strong',
            ]
        );

        $this->add_control(
            'item_sub_title_color',
            [
                'label' => esc_html__('Item Sub Title Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-event-widget .swp-details li p' => 'color: {{VALUE}}',
                ],
            ]
        );

        //item sub  title typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'Item_SUb_title_typography',
                'label'          => esc_html__('Item Sub Title Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-event-widget .swp-details li p',
            ]
        );

        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__('Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-widget' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__('Icon Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-event-widget .swp-details li p i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' => esc_html__('Border Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-widget' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {

        $settings = $this->get_settings();
?>
        <div class="swp-widget swp-event-widget">
            <?php if (!empty($settings['title'])) : ?>
                <h4 class="swp-event-title"><?php echo esc_html($settings['title']); ?></h4>
            <?php endif; ?>
            <?php if (is_array($settings['items'])) : ?>
                <ul class="swp-details">
                    <?php foreach ($settings['items'] as $item) : ?>
                        <li>
                            <strong><?php echo esc_html($item['title']); ?></strong>
                            <p><?php \Elementor\Icons_Manager::render_icon($item['icon'], ['aria-hidden' => 'true', 'class' => ' '], 'i'); ?><?php echo esc_html($item['sub_title']); ?></p>
                        </li>
                    <?php endforeach; ?>
                </ul>
            <?php endif; ?>
        </div>
<?php
    }
}

plugin::instance()->widgets_manager->register(new Swp_Eventpress_Sidebar());
