<?php

namespace Elementor;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


/**
 *
 * swp-eventpress elementor Contact widget.
 *
 * @since 1.0
 */
class Swp_Eventpress_Speaker extends Widget_Base
{

    public function get_name()
    {
        return 'swp-eventpress-speaker';
    }

    public function get_title()
    {
        return esc_html__('Speaker', 'swp-eventpress');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return ['swp-eventpress-details'];
    }

    protected function register_controls()
    {

        // general settings
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'swp-eventpress'),
            ]
        );


        $this->add_control(
            'name',
            [
                'label'   => esc_html__('Name', 'swp-eventpress'),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__('Michael S. Galicia', 'swp-eventpress'),
                'label_block' => true
            ]
        );

        $this->add_control(
            'url',
            [
                'label' => __('Url', 'swp-eventpress'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'swp-eventpress'),
                'desc' => __('Keep Blank To Remove Url', 'swp-eventpress'),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->add_control(
            'designation',
            [
                'label'   => esc_html__('Designation', 'swp-eventpress'),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__('Senior Speakers', 'swp-eventpress'),
                'label_block' => true
            ]
        );

        $this->add_control(
            'image',
            [
                'label'   => esc_html__('Image', 'swp-eventpress'),
                'type'    => Controls_Manager::MEDIA,
            ]
        );


        $this->end_controls_section(); // End general settings


        // style
        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__(' Style', 'swp-eventpress'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => esc_html__('Name Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-team-inner .content-box .inner-title a, {{WRAPPER}} .swp-single-team-inner .content-box .inner-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        //name typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'name_typography',
                'label'          => esc_html__('Name Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-single-team-inner .content-box .inner-title a, {{WRAPPER}} .swp-single-team-inner .content-box .inner-title',
            ]
        );


        $this->add_control(
            'designation_color',
            [
                'label' => esc_html__('Designation Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-team-inner .content-box p' => 'color: {{VALUE}}',
                ],
            ]
        );


        //designation typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'designation_typography',
                'label'          => esc_html__('Designation Typography', 'swp-eventpress'),
                'selector'       => '{{WRAPPER}} .swp-single-team-inner .content-box p',
            ]
        );

        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__('Background Color', 'swp-eventpress'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swp-single-team-inner' => 'background-color: {{VALUE}}',
                ],
            ]
        );


        $this->end_controls_section();
    }

    protected function render()
    {

        $settings = $this->get_settings();
?>
        <div class="swp-single-team-inner">
            <?php if (!empty($settings['image']['url'])) : ?>
                <div class="icon-img">
                    <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="img" />
                </div>
            <?php endif; ?>
            <div class="content-box">
                <h4 class="inner-title">
                    <?php if (!empty($settings['url']['url'])) : ?>
                        <a <?php echo esc_attr(!empty($settings['url']['is_external']) ? 'target=_blank' : ' '); ?> href="<?php echo esc_url($settings['url']['url']); ?>">
                            <?php echo esc_html($settings['name']); ?>
                        </a>
                    <?php else : ?>
                        <?php echo esc_html($settings['name']); ?>
                    <?php endif; ?>
                </h4>
                <p><?php echo esc_html($settings['designation']); ?></p>
            </div>
        </div>
<?php
    }
}

plugin::instance()->widgets_manager->register(new Swp_Eventpress_Speaker());
